@@ -14,7 +14,7 @@ import datetime
 from collections import defaultdict
 
 
-__version__ = '1.26.1'
+__version__ = '1.26.3'
 _PARAMS = re.compile(r'{\w+}')
 
 # Implementation note:  This file is intended to be a standalone file
@@ -106,10 +106,6 @@ class WebsocketDisconnectedError(ChaliceError):
 class ChaliceViewError(ChaliceError):
     STATUS_CODE = 500
 
-    def __init__(self, msg=''):
-        super(ChaliceViewError, self).__init__(
-            self.__class__.__name__ + ': %s' % msg)
-
 
 class ChaliceUnhandledError(ChaliceError):
     """This error is not caught from a Chalice view function.
@@ -609,7 +605,17 @@ class WebsocketAPI(object):
         if self._endpoint is not None:
             return
         region_name = self._get_region()
-        domain_name = '{api_id}.execute-api.{region}.amazonaws.com'.format(
+
+        if region_name.startswith("cn-"):
+            domain_name_template = (
+                '{api_id}.execute-api.{region}.amazonaws.com.cn'
+            )
+        else:
+            domain_name_template = (
+                '{api_id}.execute-api.{region}.amazonaws.com'
+            )
+
+        domain_name = domain_name_template.format(
             api_id=api_id, region=region_name)
         self.configure(domain_name, stage)
 
